pub struct NotebookService { /* private fields */ }Expand description
Implements a client for the Notebooks API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = NotebookService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_instances()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
API v2 service for Workbench Notebooks Instances.
Configuration
To configure NotebookService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://notebooks.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
NotebookService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap NotebookService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl NotebookService
impl NotebookService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for NotebookService.
let client = NotebookService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: NotebookService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: NotebookService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_instances(&self) -> ListInstances
pub fn list_instances(&self) -> ListInstances
Lists instances in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService, parent: &str
) -> Result<()> {
let mut list = client.list_instances()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_instance(&self) -> GetInstance
pub fn get_instance(&self) -> GetInstance
Gets details of a single Instance.
Example
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService, name: &str
) -> Result<()> {
let response = client.get_instance()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_instance(&self) -> CreateInstance
pub fn create_instance(&self) -> CreateInstance
Creates a new Instance in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_notebooks_v2::model::Instance;
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService, parent: &str
) -> Result<()> {
let response = client.create_instance()
.set_parent(parent)
.set_instance_id("instance_id_value")
.set_instance(
Instance::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_instance(&self) -> UpdateInstance
pub fn update_instance(&self) -> UpdateInstance
UpdateInstance updates an Instance.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_notebooks_v2::model::Instance;
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService, name: &str
) -> Result<()> {
let response = client.update_instance()
.set_instance(
Instance::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_instance(&self) -> DeleteInstance
pub fn delete_instance(&self) -> DeleteInstance
Deletes a single Instance.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService, name: &str
) -> Result<()> {
client.delete_instance()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn start_instance(&self) -> StartInstance
pub fn start_instance(&self) -> StartInstance
Starts a notebook instance.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.start_instance()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn stop_instance(&self) -> StopInstance
pub fn stop_instance(&self) -> StopInstance
Stops a notebook instance.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.stop_instance()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn reset_instance(&self) -> ResetInstance
pub fn reset_instance(&self) -> ResetInstance
Resets a notebook instance.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.reset_instance()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn check_instance_upgradability(&self) -> CheckInstanceUpgradability
pub fn check_instance_upgradability(&self) -> CheckInstanceUpgradability
Checks whether a notebook instance is upgradable.
Example
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.check_instance_upgradability()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn upgrade_instance(&self) -> UpgradeInstance
pub fn upgrade_instance(&self) -> UpgradeInstance
Upgrades a notebook instance to the latest version.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.upgrade_instance()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn rollback_instance(&self) -> RollbackInstance
pub fn rollback_instance(&self) -> RollbackInstance
Rollbacks a notebook instance to the previous version.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.rollback_instance()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn diagnose_instance(&self) -> DiagnoseInstance
pub fn diagnose_instance(&self) -> DiagnoseInstance
Creates a Diagnostic File and runs Diagnostic Tool given an Instance.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.diagnose_instance()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_notebooks_v2::Result;
async fn sample(
client: &NotebookService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for NotebookService
impl Clone for NotebookService
Sourcefn clone(&self) -> NotebookService
fn clone(&self) -> NotebookService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more